EasyExtend.langlets.p4d.langlet.LangletImporter

Package EasyExtend :: Package langlets :: Package p4d :: Module langlet :: Class LangletImporter |
[hide private]
[frames] | no frames]

# Class LangletImporter

             object --+
                      |
    eeimporter.Importer --+
                          |
                         LangletImporter

Defines langlet specific import behaviour.

Instance Methods | [hide private]
Inherited from `eeimporter.Importer`: `__init__`, `accept_module`, `find_module`, `is_langletmodule`, `langlet_compiler`, `langlet_path`, `load_module`, `module_loader`, `pre_filter`, `register_importer` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
Inherited from `eeimporter.Importer`: `no_import`

Properties | [hide private]
Inherited from `object`: `__class__`